@@ -11,8 +11,8 @@ class PlayerPlotter(Plotter):
 		super().__init__(res_file, conf_file)
 
 	def plot_soc(self, name="PLAYER"):
-		fig = super().plot_soc()#.show()
-		pio.write_image(fig, "outputs/PLAYER-soc.png")
+		fig = super().plot_soc(name)#.show()
+		pio.write_image(fig, f"outputs/{name}-soc.png")
 		return 
 
 	def plot_community_peak(self):
